NAs: The 'datey', 'durationy' and 'datey_interval' versions of NA

NAsR Documentation

The datey, durationy and datey_interval versions of NA

Description

Throughout the datey package, NA will cause an error when used where a datey_, durationy_ or datey_interval_ is expected. This is because its type is logical and potentially indicates user error. If you want an NA value with a datey system type, use one of NA_datey_, NA_durationy_ or NA_datey_interval_.

Usage

NA_datey_

NA_datey_interval_

NA_durationy_

Value

Each is a scalar holding the missing-value (NA) representation of its type: NA_datey_ is a datey, NA_durationy_ is a durationy and NA_datey_interval_ is a datey_interval.

See Also

is_NA, integer_constants, datey, durationy, datey_interval

Examples

  is_datey(NA_datey_)
  is.na(NA_datey_)
  is_durationy(NA_durationy_)
  is.na(NA_durationy_)
  is_datey_interval(NA_datey_interval_)

datey documentation built on July 14, 2026, 5:06 p.m.