| is_type | R Documentation |
x a datey, durationy or datey_interval?These methods will always return a scalar logical TRUE or FALSE:
is_datey() tests whether an object is a datey.
is_durationy() tests whether an object is a durationy.
is_datey_interval() tests whether an object is a datey_interval.
is_datey(x)
is_datey_interval(x)
is_durationy(x)
x |
The object to test. |
A logical scalar indicating whether x a datey, durationy or
datey_interval as appropriate.
Always FALSE or TRUE; never NULL or NA.
t <- datey(2000:2001)
t
is_datey(t)
is_datey(NULL)
is_datey(NA)
d <- durationy(0:2)
d
is_durationy(d)
is_durationy(NULL)
is_durationy(NA)
interval <- datey(2000:2001) %to% datey(2001:2002)
interval
is_datey_interval(interval)
is_datey_interval(NULL)
is_datey_interval(NA)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.