| max_min | R Documentation |
datey or durationyGets the minimum, maximum or range of one or more datey or durationy
vectors. All arguments must be of the same type.
Returns a typed NA (NA_datey_ or NA_durationy_) for empty input or
when all values are NA and na.rm = TRUE.
These are S3 methods for the Summary group generic.
## S3 method for class 'datey_interval'
Summary(..., na.rm = FALSE)
## S3 method for class 'datey'
Summary(..., na.rm = FALSE)
## S3 method for class 'durationy'
Summary(..., na.rm = FALSE)
... |
One or more |
na.rm |
A logical ( |
min and max return a scalar.
range returns a two element vector,
the first element being the minimum and the second the maximum.
datey, durationy, mean.datey
t <- datey(2000:2003)
t
min(t)
max(t)
range(t)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.