| mean | R Documentation |
datey or durationyGets the mean value of a vector of datey or durationy as a scalar.
This will entail rounding if the mean of the underlying click counts is not an integer.
These are S3 methods for the mean generic.
## S3 method for class 'datey_interval'
mean(x, ..., na.rm = FALSE)
## S3 method for class 'datey'
mean(x, ..., na.rm = FALSE)
## S3 method for class 'durationy'
mean(x, ..., na.rm = FALSE)
x |
The |
... |
Not used. |
na.rm |
A logical ( |
A scalar of datey or durationy as appropriate.
datey, durationy, max_min
t <- datey(2000:2003)
t
mean(t)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.